MatchThem ObjectsGenerates balance statistics for mimids and wimids objects from MatchThem.
# S3 method for mimids
bal.tab(x,
stats,
int = FALSE,
poly = 1,
distance = NULL,
addl = NULL,
data = NULL,
continuous,
binary,
s.d.denom,
thresholds = NULL,
weights = NULL,
cluster = NULL,
pairwise = TRUE,
s.weights = NULL,
abs = FALSE,
subset = NULL,
quick = TRUE,
...)If clusters are not specified, an object of class "bal.tab.imp" containing balance summaries for each imputation and a summary of balance across imputations. See bal.tab.imp for details.
If clusters are specified, an object of class "bal.tab.imp.cluster" containing summaries between and across all clusters and imputations.
a mimids or wimids object; the output of a call to MatchThem::matchthem() or MatchThem::weightthem().
see bal.tab() for details.
See below for special notes on the distance, s.d.denom, and imp arguments. Note the imp argument is ignored because the imputation identifers are already present in the input object.
The following arguments have special notes when used with mimids and wimids objects:
the distance measure generated by matchthem() or weightthem() is automatically included and named "distance" or "prop.score", respectively.
the defaults depend on the options specified in the original function calls; see bal.tab.matchit() and bal.tab.weightit() for details on the defaults.
Noah Greifer
bal.tab.mimids() and bal.tab.wimids() generate a list of balance summaries for the mimids or wimids object given.
bal.tab() for details of calculations.
bal.tab.matchit() and bal.tab.weightit()