One of the datasets used by Dehejia and Wahba in their paper "Causal Effects in Non-Experimental Studies: Reevaluating the Evaluation of Training Programs." Versions of this data set have been used as an example data set in MatchIt, twang, Matching, and CBPS. The data set lalonde_mis is the same but with some values missing (set to NA).
data("lalonde")
data("lalonde_mis")A data frame with 614 observations on the following 9 variables.
treat1 if treated in the National Supported Work Demonstration, 0 if from the Current Population Survey
ageage
educyears of education
racefactor; black, Hispanic (hispan), or white
married1 if married, 0 otherwise
nodegree1 if no degree, 0 otherwise
re74earnings in 1974 (pretreatment)
re75earnings in 1975 (pretreatment)
re78earnings in 1978 (outcome)
Lalonde, R. (1986). Evaluating the econometric evaluations of training programs with experimental data. American Economic Review 76: 604-620.
Dehejia, R.H. and Wahba, S. (1999). Causal Effects in Nonexperimental Studies: Re-Evaluating the Evaluation of Training Programs. Journal of the American Statistical Association 94: 1053-1062.